// 'i_mca_figurine_inc'
//
// Include file for Figurines.
// - designed by Sabranic
// - scripted by kevL
// ed.2016 dec 16

#include "x2_inc_itemprop"

// ___________________
// ** DECLARATIONS ***
// -------------------

// Summons a creature.
void summon(string sResref, int iDur);

// Buffs the summoned creature.
void buff();


// __________________
// ** DEFINITIONS ***
// ------------------

// Summons a creature.
// - OBJECT_SELF is ItemActivator: the effect must be created/applied by a member
//   of the party that the summoned-associate will join.
void summon(string sResref, int iDur)
{
    effect eSummon = EffectSummonCreature(sResref, VFX_FNF_SUMMON_MONSTER_3, 0.3f);
    ApplyEffectAtLocation(DURATION_TYPE_TEMPORARY,
                          eSummon,
                          GetItemActivatedTargetLocation(),
                          TurnsToSeconds(iDur));
    DelayCommand(2.f, buff());
}


// Buffs the summoned creature.
// - OBJECT_SELF is ItemActivator.
void buff()
{
    object oPet = GetAssociate(ASSOCIATE_TYPE_SUMMONED);

    // Heal to full hp
    int hpCur = GetCurrentHitPoints(oPet);
    int hpMax = GetMaxHitPoints(oPet);

    int hpHeal = hpMax - hpCur;
    if (hpHeal > 0)
    {
        effect eHeal = EffectHeal(hpHeal);
        ApplyEffectToObject(DURATION_TYPE_INSTANT, eHeal, oPet);
    }


    // apply Animalistic Power
    effect eStr = EffectAbilityIncrease(ABILITY_STRENGTH, 2);
    effect eDex = EffectAbilityIncrease(ABILITY_DEXTERITY, 2);
    effect eCon = EffectAbilityIncrease(ABILITY_CONSTITUTION, 2);

    effect eLink = EffectLinkEffects(eStr, eDex);
    eLink        = EffectLinkEffects(eCon, eLink);
    eLink        = SetEffectSpellId(eLink, SPELL_ANIMALISTIC_POWER); // #1168

    ApplyEffectToObject(DURATION_TYPE_PERMANENT, eLink, oPet);


    // add Greater Magic Fang and Jagged Tooth
    // Note that itemproperties do not store SpellIDs.
    // SPELL_GREATER_MAGIC_FANG #453
    // SPELL_JAGGED_TOOTH #1002
    itemproperty ipFang  = ItemPropertyEnhancementBonus(DAMAGE_POWER_PLUS_FIVE);
    itemproperty ipTooth = ItemPropertyKeen();

    object oWeapon = GetItemInSlot(INVENTORY_SLOT_CWEAPON_B, oPet); // bite
    if (GetIsObjectValid(oWeapon))
    {
        IPSafeAddItemProperty(oWeapon, ipFang);

        if (!IPGetIsBludgeoningWeapon(oWeapon))
            IPSafeAddItemProperty(oWeapon, ipTooth);
    }

    oWeapon = GetItemInSlot(INVENTORY_SLOT_CWEAPON_R, oPet); // right
    if (GetIsObjectValid(oWeapon))
    {
        IPSafeAddItemProperty(oWeapon, ipFang);

        if (!IPGetIsBludgeoningWeapon(oWeapon))
            IPSafeAddItemProperty(oWeapon, ipTooth);
    }

    oWeapon = GetItemInSlot(INVENTORY_SLOT_CWEAPON_L, oPet); // left
    if (GetIsObjectValid(oWeapon))
    {
        IPSafeAddItemProperty(oWeapon, ipFang);

        if (!IPGetIsBludgeoningWeapon(oWeapon))
            IPSafeAddItemProperty(oWeapon, ipTooth);
    }
}